DnaString

Struct DnaString 

pub struct DnaString { /* private fields */ }
A container for sequence of DNA bases.

use debruijn::dna_string::DnaString;
use debruijn::kmer::Kmer8;
use debruijn::{Mer, Vmer};

let dna_string = DnaString::from_dna_string("ATCGTACGTACGTAGTC");

// Iterate over 8-mers
for k in dna_string.iter_kmers::<Kmer8>() {
    println!("{:?}", k);
}

// Get a base, encoded as a byte in 0-3 range
assert_eq!(dna_string.get(0), 0);
assert_eq!(dna_string.get(1), 3);

// Make a read-only 'slice' of a DnaString
let slc = dna_string.slice(1, 10);

 assert_eq!(slc.iter_kmers::<Kmer8>().next(), dna_string.iter_kmers::<Kmer8>().skip(1).next());

Implementations

Source

impl DnaString

pub fn new() -> DnaString

Create an empty DNA string

pub fn len(&self) -> usize

Length of the sequence

pub fn with_capacity(n: usize) -> Self

Create a new instance with a given capacity.

pub fn blank(n: usize) -> Self

Create a DnaString of length n initialized to all A’s

pub fn from_dna_string(dna: &str) -> DnaString

Create a DnaString corresponding to an ACGT-encoded str.

pub fn from_dna_only_string(dna: &str) -> Vec<DnaString>

Create a DnaString corresponding to an ACGT-encoded str.

pub fn from_acgt_bytes(bytes: &[u8]) -> DnaString

Create a DnaString from an ASCII ACGT-encoded byte slice. Non ACGT positions will be converted to ‘A’

pub fn from_acgt_bytes_checked( bytes: &[u8], ) -> Result<DnaString, AmbiguousBasesError>

Create a DnaString from an ASCII ACGT-encoded byte slice. Will return None if there are ambiguous bases in the DnaString

pub fn from_acgt_bytes_hashn(bytes: &[u8], read_name: &[u8]) -> DnaString

Create a DnaString from an ACGT-encoded byte slice, Non ACGT positions will be converted to repeatable random base determined by a hash of the read name and the position within the string.

pub fn from_bytes(bytes: &[u8]) -> DnaString

Create a DnaString from a 0-4 encoded byte slice

pub fn to_bytes(&self) -> Vec<u8>

Convert sequence to a Vector of 0-4 encoded bytes

pub fn to_ascii_vec(&self) -> Vec<u8>

Convert sequence to a Vector of ascii-encoded bytes

pub fn push(&mut self, value: u8)

Append a 0-4 encoded base.

pub fn extend(&mut self, bytes: impl Iterator<Item = u8>)

pub fn push_bytes(&mut self, bytes: &[u8], seq_length: usize)

Push 0-4 encoded bases from a byte array.

Arguments

bytes: byte array to read values from seq_length: how many values to read from the byte array. Note that this is number of values not number of elements of the byte array.

pub fn iter(&self) -> DnaStringIter<'_>

Iterate over stored values (values will be unpacked into bytes).

pub fn clear(&mut self)

Clear the sequence.

pub fn is_empty(&self) -> bool

pub fn prefix(&self, k: usize) -> DnaStringSlice<'_>

Get the length k prefix of the DnaString

pub fn suffix(&self, k: usize) -> DnaStringSlice<'_>

Get the length k suffix of the DnaString

pub fn slice(&self, start: usize, end: usize) -> DnaStringSlice<'_>

Get slice containing the interval [start, end) of self

pub fn reverse(&self) -> DnaString

Create a fresh DnaString containing the reverse of self

pub fn hamming_distance(&self, other: &DnaString) -> usize

Compute Hamming distance between this DnaString and another DnaString. The two strings must have the same length.

pub fn shrink_to_fit(&mut self)

shrink the storage of the DnaString to fit its contents