pub struct PackedDnaStringSet {
pub sequence: DnaString,
pub start: Vec<usize>,
pub length: Vec<u32>,
}Expand description
Container for many distinct sequences, concatenated into a single DnaString. Each sequence is accessible by index as a DnaStringSlice.
Fields
sequence: DnaStringstart: Vec<usize>length: Vec<u32>Implementations
Sourceimpl PackedDnaStringSet
impl PackedDnaStringSet
Sourcepub fn get(&self, i: usize) -> DnaStringSlice<'_>
pub fn get(&self, i: usize) -> DnaStringSlice<'_>
Get a DnaStringSlice containing ith sequence in the set
Sourcepub fn slice(&self, i: usize, start: usize, end: usize) -> DnaStringSlice<'_>
pub fn slice(&self, i: usize, start: usize, end: usize) -> DnaStringSlice<'_>
Get a DnaStringSlice containing ith sequence in the set
pub fn is_empty(&self) -> bool
pub fn add<R: Borrow<u8>, S: IntoIterator<Item = R>>(&mut self, sequence: S)
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
shrink the storage of the PackedDnaStringSet to fit its contents